@@ -3,15 +3,25 @@ use 5.006;
 use strict;
 use warnings;
 
-use Carp qw(croak);
+use Carp qw(confess);
 use Mock::Sub::Child;
 use Scalar::Util qw(weaken);
 
-our $VERSION = '1.06';
+our $VERSION = '1.07';
 
+my %opts;
+
+sub import {
+    my ($class, %args) = @_;
+    %opts = %args;
+}
 sub new {
     my $self = bless {}, shift;
     %{ $self } = @_;
+
+    for (keys %opts){
+        $self->{$_} = $opts{$_};
+    }
     return $self;
 }
 sub mock {
@@ -19,7 +29,7 @@ sub mock {
     my $sub = shift;
 
     if (ref($self) ne 'Mock::Sub'){
-        croak
+        confess
             "calling mock() on the Mock::Sub class is no longer permitted. " .
             "create a new mock object with Mock::Sub->new;, then call mock " .
             "with my \$sub_object = \$mock->mock('sub_name'); ";
@@ -30,10 +40,10 @@ sub mock {
     }
 
     if (! defined wantarray){
-        croak "\n\ncalling mock() in void context isn't allowed. ";
+        confess "\n\ncalling mock() in void context isn't allowed. ";
     }
 
-    my $child = Mock::Sub::Child->new;
+    my $child = Mock::Sub::Child->new(no_warnings => $self->{no_warnings});
 
     $child->side_effect($self->{side_effect});
     $child->return_value($self->{return_value});
@@ -71,7 +81,7 @@ sub mocked_state {
     my ($self, $sub) = @_;
 
     if (! $sub){
-        croak "calling mocked_state() on a Mock::Sub object requires a sub " .
+        confess "calling mocked_state() on a Mock::Sub object requires a sub " .
               "name to be passed in as its only parameter. ";
     }
 
@@ -79,7 +89,7 @@ sub mocked_state {
         my $test = $self->{objects}{$sub}{obj}->mocked_state();
     };
     if ($@){
-        croak "can't call mocked_state() on the class if the sub hasn't yet " .
+        confess "can't call mocked_state() on the class if the sub hasn't yet " .
               "been mocked. ";
     }
     return $self->{objects}{$sub}{obj}->mocked_state;
@@ -103,6 +113,10 @@ Mock::Sub - Mock package, object and standard subroutines, with unit testing in
 
     use Mock::Sub;
 
+    # disable warnings about mocking non-existent subs
+
+    use Mock::Sub no_warnings => 1
+
     # create the parent mock object
 
     my $mock = Mock::Sub->new;
@@ -234,7 +248,7 @@ MyModule::first).
 =head2 C<new(%opts)>
 
 Instantiates and returns a new C<Mock::Sub> object, ready to be used to start
-cteating mocked sub objects.
+creating mocked sub objects.
 
 Optional options:
 
@@ -274,8 +288,8 @@ set, change or remove these values after instantiation of a child sub object.
 
 =head2 mocked_subs
 
-Returns a list of all subs that are currently mocked under the parent mock
-object.
+Returns a list of all the names of the subs that are currently mocked under
+the parent mock object.
 
 =head2 mocked_objects
 
@@ -284,8 +298,9 @@ if its sub is currently mocked or not.
 
 =head2 mocked_state('Sub::Name')
 
-Returns whether a sub currently under the parent mock object is mocked or not.
-Croaks if there hasn't been a child sub object created with this sub name.
+Returns 1 if the sub currently under the parent mock object is mocked or not,
+and 0 if not. Croaks if there hasn't been a child sub object created with this
+sub name.
 
 =head1 SUB OBJECT METHODS
 
@@ -305,7 +320,7 @@ side_effect and return_value parameters).
 
 =head2 C<called>
 
-Returns true if the sub being mocked has been called.
+Returns true (1) if the sub being mocked has been called, and false (0) if not.
 
 =head2 C<called_count>
 
@@ -313,13 +328,13 @@ Returns the number of times the mocked sub has been called.
 
 =head2 C<called_with>
 
-Returns an array of the parameters sent to the subroutine. C<croak()s> if
+Returns an array of the parameters sent to the subroutine. C<confess()s> if
 we're called before the mocked sub has been called.
 
 =head2 C<mocked_state>
 
-Returns true (1) if the sub the object refers to is currently mocked, and false if
-not.
+Returns true (1) if the sub the object refers to is currently mocked, and
+false (0) if not.
 
 =head2 C<name>
 
