@@ -3,10 +3,10 @@ use 5.006;
 use strict;
 use warnings;
 
-use Carp qw(croak);
+use Carp qw(confess);
 use Scalar::Util qw(weaken);
 
-our $VERSION = '1.05';
+our $VERSION = '1.07';
 
 sub new {
     my $self = bless {}, shift;
@@ -17,7 +17,7 @@ sub new {
     }
     return $self;
 }
-sub mock {
+sub _mock {
     my $self = shift;
 
     # throw away the sub name if it's sent in and we're not called
@@ -29,15 +29,20 @@ sub mock {
     }
 
     my $caller = (caller(1))[3] || '';
-
+    
     if ($caller ne 'Mock::Sub::mock' && $sub_passed_in){
         undef @_;
         if(ref($self) eq 'Mock::Sub::Child' && ! $self->{name}){
-            croak "can't call mock() on a child object before it is already " .
+            confess "can't call mock() on a child object before it is already " .
                   "initialized with the parent mock object. ";
         }
     }
 
+    if ($caller ne 'Mock::Sub::mock' && $caller ne 'Mock::Sub::Child::remock'){
+        confess "the _mock() method is not a public API call. For re-mocking " .
+              "an existing sub in an existing sub object, use remock().\n";
+    }
+
     my $sub = $self->name || shift;
 
     my %p = @_;
@@ -62,10 +67,12 @@ sub mock {
 
     my $fake;
 
-    if (! exists &$sub && $sub !~ /CORE::GLOBAL/){
+    if (! exists &$sub && $sub !~ /CORE::GLOBAL/) {
         $fake = 1;
-        warn "\n\nWARNING!: we've mocked a non-existent subroutine. " .
-             "the specified sub does not exist.\n\n";
+        if (! $self->_no_warn) {
+            warn "\n\nWARNING!: we've mocked a non-existent subroutine. ".
+                    "the specified sub does not exist.\n\n";
+        }
     }
 
     $self->_check_side_effect($self->{side_effect});
@@ -113,6 +120,9 @@ sub mock {
 
     return $self;
 }
+sub remock {
+    shift->_mock(@_);
+}
 sub unmock {
     my $self = shift;
     my $sub = $self->{name};
@@ -141,7 +151,7 @@ sub called_count {
 sub called_with {
     my $self = shift;
     if (! $self->called){
-        croak "\n\ncan't call called_with() before the mocked sub has " .
+        confess "\n\ncan't call called_with() before the mocked sub has " .
             "been called. ";
     }
     return @{ $self->{called_with} };
@@ -164,12 +174,15 @@ sub side_effect {
 }
 sub _check_side_effect {
     if (defined $_[1] && ref $_[1] ne 'CODE') {
-        croak "\n\nside_effect parameter must be a code reference. ";
+        confess "\n\nside_effect parameter must be a code reference. ";
     }
 }
 sub mocked_state {
     return shift->{state};
 }
+sub _no_warn {
+    return $_[0]->{no_warnings};
+}
 sub DESTROY {
     $_[0]->unmock;
 }
@@ -188,27 +201,6 @@ descriptions here are just a briefing.
 
 =head2 new
 
-This method can only be called by the parent C<Mock::Sub> module.
-=head2 new
-
-This method can only be called by the parent C<Mock::Sub> module.
-=head2 new
-
-This method can only be called by the parent C<Mock::Sub> module.
-=head2 new
-
-This method can only be called by the parent C<Mock::Sub> module.
-=head2 new
-
-This method can only be called by the parent C<Mock::Sub> module.
-=head2 new
-
-This method can only be called by the parent C<Mock::Sub> module.
-=head2 new
-
-This method can only be called by the parent C<Mock::Sub> module.
-=head2 new
-
 This method can only be called by the parent C<Mock::Sub> module.
 
 =head2 called
@@ -225,6 +217,11 @@ Returns a list of arguments the mocked sub was called with.
 
 =head2 mock
 
+This method should only be called by the parent mock object. You shouldn't be
+calling this.
+
+=head2 remock
+
 Re-mocks an unmocked sub back to the same subroutine it was originally mocked with.
 
 =head2 mocked_state
